@@ -92,6 +92,10 @@ class GPIOSettings(util.DisableNewAttr):
         self.disable_newattr()
 
 
+    def read_tio_states(self):
+        bitmask = self.cwe.readTIOPins()
+        return tuple(((bitmask >> i) & 0x01) for i in range(4))
+
     def _dict_repr(self):
         dict = OrderedDict()
         dict['tio1'] = self.tio1
@@ -111,8 +115,30 @@ class GPIOSettings(util.DisableNewAttr):
 
         dict['target_pwr'] = self.target_pwr
 
+        dict['tio_states'] = self.tio_states
+
         return dict
 
+    @property
+    def tio_states(self):
+        """
+        Reads the logic level of the TIO pins (1-4) and
+        returns them as a tuple of the logic levels. 
+
+        .. warning:: ChipWhisperer firmware before release 5.2.1 does not support
+            reading the TIO pins!
+
+        :getter: Read TIO states
+
+        Returns:
+            A tuple of 1's and 0's representing the logic levels
+            of each TIO pin
+
+        .. versionadded:: 5.3
+            Add documented interface for the old method of reading TIO pins
+        """
+        return self.read_tio_states()
+
     def __repr__(self):
         return util.dict_to_str(self._dict_repr())
 
@@ -471,6 +497,10 @@ class GPIOSettings(util.DisableNewAttr):
 
         This is the low-power version of glitch_hp - see that documentation
         for more details.
+
+        .. warning:: Use with caution - ensure that the glitch module is properly
+            configured before enabling this setting, as it is possible to
+            permanently damage hardware with this output.
         """
         return self.cwe.targetGlitchOut('B')
 
