@@ -522,5 +522,21 @@ class SimpleSerial(TargetTemplate, util.DisableNewAttr):
         """
         self.ser.flush()
 
+    def in_waiting_tx(self):
+        """Returns the number of characters waiting to be sent by the ChipWhisperer.
+
+        Requires firmware version >= 0.2 for the CWLite/Nano and firmware version and
+        firmware version >= 1.2 for the CWPro.
+
+        Used internally to avoid overflowing the TX buffer, since CW version 5.3
+
+        Returns:
+            The number of characters waiting to be sent to the target
+
+        .. versionadded:: 5.3.1
+            Added public method for in_waiting_tx().
+        """
+        return self.ser.inWaitingTX()
+
 
 
